import { Component, OnInit, ViewChild } from "@angular/core";
import { MainService } from "../../services/main.service";
import { Router } from "@angular/router";
import { OverlayScrollbarsComponent } from "overlayscrollbars-ngx";

@Component({
  selector: "app-pharmacy",
  templateUrl: "./pharmacy.component.html",
  styleUrls: ["./pharmacy.component.less"],
})
export class PharmacyComponent implements OnInit {
  @ViewChild("osComponentRef1", {
    read: OverlayScrollbarsComponent,
    static: false,
  })
  osComponentRef1: OverlayScrollbarsComponent;
  @ViewChild("osComponentRef2", {
    read: OverlayScrollbarsComponent,
    static: false,
  })
  osComponentRef2: OverlayScrollbarsComponent;
  @ViewChild("osComponentRef3", {
    read: OverlayScrollbarsComponent,
    static: false,
  })
  osComponentRef3: OverlayScrollbarsComponent;
  constructor(private mainService: MainService, public router: Router) {}
  //打印二维码数据
  codes = [];
  // 登录切换效果
  loginFlag = false;
  // 打印二维码
  printPharmacyList = []; //数据列表
  printPharmacyIdx = 0; //页码
  printPharmacyFlag = false; //是否查看更多
  printPharmacySearchKey = ""; //搜索的内容
  printPharmacyLoad = false; //按钮的loading
  // 待配送列表
  waitPharmacyList = [];
  waitPharmacyIdx = 0;
  waitPharmacyFlag = false;
  waitPharmacySearchKey = "";
  waitPharmacyLoad = false;
  // 已配送列表
  pharmacyList = [];
  pharmacyIdx = 0;
  pharmacyFlag = false;
  pharmacySearchKey = "";
  pharmacyLoad = false;
  //当前登录人所属科室
  currentDept = "";

  ngOnInit() {
    // 打印二维码列表
    this.getPharmacyList(this.printPharmacyIdx, 1, this.printPharmacySearchKey);
    // 待配送列表
    this.getPharmacyList(this.waitPharmacyIdx, 2, this.waitPharmacySearchKey);
    // 已配送列表
    this.getPharmacyList(this.pharmacyIdx, 3, this.pharmacySearchKey);
    //当前登录人所属科室
    this.currentDept = JSON.parse(localStorage.getItem("user")).user.dept.dept;

    this.initRole();
  }
  // 药房端药房列表查询、搜索
  // 1为pc待打印状态、2为pc待配送、3为pc已配送
  // searchKey  为搜索的关键字，没有就不传
  loading1 = false;
  loading2 = false;
  loading3 = false;
  getPharmacyList(idx, type, searchKey) {
    let launch = {
      id: JSON.parse(localStorage.getItem("user")).user.dept.id,
    };
    switch (type) {
      case 1:
        this.loading1 = true;
        break;
      case 2:
        this.loading2 = true;
        break;
      case 3:
        this.loading3 = true;
        break;
    }
    this.mainService
      .getPharmacyList(idx, type, searchKey, launch)
      .subscribe((result) => {
        switch (type) {
          case 1:
            this.loading1 = false;
            break;
          case 2:
            this.loading2 = false;
            break;
          case 3:
            this.loading3 = false;
            break;
        }
        if (result["status"] == 200) {
          switch (type) {
            case 1:
              // 隐藏按钮的loading
              this.printPharmacyLoad = false;
              // 查看更多，是否显示
              if (result["list"].length < 10) {
                this.printPharmacyFlag = false;
              } else if (result["list"].length === 0 && idx === 0) {
                this.printPharmacyFlag = false;
              } else {
                this.printPharmacyFlag = true;
              }
              // 列表数据合并
              this.printPharmacyList = [
                ...this.printPharmacyList,
                ...result["list"],
              ];
              break;
            case 2:
              this.waitPharmacyLoad = false;
              if (result["list"].length < 10) {
                this.waitPharmacyFlag = false;
              } else if (result["list"].length === 0 && idx === 0) {
                this.waitPharmacyFlag = false;
              } else {
                this.waitPharmacyFlag = true;
              }
              this.waitPharmacyList = [
                ...this.waitPharmacyList,
                ...result["list"],
              ];
              break;
            case 3:
              this.pharmacyLoad = false;
              if (result["list"].length < 10) {
                this.pharmacyFlag = false;
              } else if (result["list"].length === 0 && idx === 0) {
                this.pharmacyFlag = false;
              } else {
                this.pharmacyFlag = true;
              }
              this.pharmacyList = [...this.pharmacyList, ...result["list"]];
              break;
          }
        }
      });
  }
  // 加载更多
  loadMore(type) {
    switch (type) {
      case 1:
        this.printPharmacyIdx++;
        this.printPharmacyLoad = true;
        this.getPharmacyList(
          this.printPharmacyIdx,
          type,
          this.printPharmacySearchKey
        );
        break;
      case 2:
        this.waitPharmacyIdx++;
        this.waitPharmacyLoad = true;
        this.getPharmacyList(
          this.waitPharmacyIdx,
          type,
          this.waitPharmacySearchKey
        );
        break;
      case 3:
        this.pharmacyIdx++;
        this.pharmacyLoad = true;
        this.getPharmacyList(this.pharmacyIdx, type, this.pharmacySearchKey);
        break;
    }
  }
  // 搜索关键词
  searchKeyHandle(type) {
    switch (type) {
      case 1:
        this.printPharmacyIdx = 0; //页码重置
        this.printPharmacyList = []; //列表重置
        this.getPharmacyList(
          this.printPharmacyIdx,
          type,
          this.printPharmacySearchKey
        );
        break;
      case 2:
        this.waitPharmacyIdx = 0; //页码重置
        this.waitPharmacyList = []; //列表重置
        this.getPharmacyList(
          this.waitPharmacyIdx,
          type,
          this.waitPharmacySearchKey
        );
        break;
      case 3:
        this.pharmacyIdx = 0; //页码重置
        this.pharmacyList = []; //列表重置
        this.getPharmacyList(this.pharmacyIdx, type, this.pharmacySearchKey);
        break;
    }
  }
  // 退出
  logOut(): void {
    // 假退出
    localStorage.removeItem("user");
    localStorage.removeItem("menu");
    localStorage.removeItem("phones");
    localStorage.removeItem("index");
    this.router.navigateByUrl("login");
    // 假退出
    this.mainService.logOut().subscribe((data) => {
      if (data.status == 200) {
        localStorage.removeItem("user");
        localStorage.removeItem("menu");
        localStorage.removeItem("phones");
        localStorage.removeItem("index");
        this.router.navigateByUrl("login");
      }
    });
  }
  // 退出按钮切换效果
  toggleLogin() {
    this.loginFlag = !this.loginFlag;
  }
  //打印二维码
  print(id?) {
    let arr = [];
    if (typeof id === "number" && id > 0) {
      //单个二维码
      arr.push(id);
    } else {
      //批量二维码
      arr = this.printPharmacyList.map((item) => item.id);
    }
    this.mainService.printRequisition(arr).subscribe((data) => {
      if (data["status"] == 200) {
        this.codes = data["data"];
        setTimeout(function () {
          const printContent = document.getElementById("report");
          const WindowPrt = window.open("", "", "width=700,height=900");
          WindowPrt.document.write(printContent.innerHTML);
          WindowPrt.print();
          WindowPrt.close();
        }, 100);
        // 待打印变为待配药接口
        let loginName = JSON.parse(localStorage.getItem("user")).user.name;
        this.mainService
          .changeToDispensing(arr, loginName)
          .subscribe((data) => {
            if (data["state"] == 200) {
              this.printPharmacyList = [];
              this.waitPharmacyList = [];
              // 打印二维码列表
              this.getPharmacyList(0, 1, this.printPharmacySearchKey);
              // 待配送列表
              this.getPharmacyList(0, 2, this.waitPharmacySearchKey);
            }
          });
      }
    });
  }

  //补打二维码
  replenishPrint(id?) {
    let arr = [];
    if (typeof id === "number" && id > 0) {
      //单个二维码
      arr.push(id);
    } else {
      //批量二维码
      arr = this.printPharmacyList.map((item) => item.id);
    }
    this.mainService.printRequisition(arr).subscribe((data) => {
      if (data["status"] == 200) {
        this.codes = data["data"];
        setTimeout(function () {
          const printContent = document.getElementById("report");
          const WindowPrt = window.open("", "", "width=700,height=900");
          WindowPrt.document.write(printContent.innerHTML);
          WindowPrt.print();
          WindowPrt.close();
        }, 100);
      }
    });
  }

  // 右侧菜单
  showLastItems: boolean = false;
  // 下拉
  fixedMenuXiala() {
    this.showLastItems = true;
  }

  // 上拉
  fixedMenuShangla() {
    this.showLastItems = false;
  }

  mainRole: boolean = false; //回到系统管理权限
  initRole() {
    // let roles = JSON.parse(localStorage.getItem('user')).user.role;
    let menus = JSON.parse(localStorage.getItem("menu"));
    let that = this;
    console.log("菜单数量" + menus.length);
    if (menus.length >= 2) {
      that.mainRole = true;
      return;
    }
  }

  // 切换右侧菜单Tab
  fixedTab: string = "";
  checkFixedTab(type: string) {
    if (type == "toSystem") {
      this.router.navigateByUrl("main");
    }
    if (this.fixedTab == type) {
      this.fixedTab = "";
    } else {
      this.fixedTab = type;
    }
  }
}
